pub struct FileLogConfig {
pub directory_path: PathBuf,
pub format: LogFormat,
pub rotation: LogRotation,
}Expand description
Configuration for file logging.
Fields
directory_path: PathBufThe path to the directory where the log files are stored.
format: LogFormatThe format of the logs printed to the log file.
rotation: LogRotationThe rotation of the log files.