pub struct LogArgs {
pub level: u8,
pub stdout_quiet: bool,
pub stdout_format: LogFormat,
pub file_directory: Option<PathBuf>,
pub file_format: LogFormat,
pub file_rotation: LogRotation,
}Expand description
Global configuration arguments.
Fields
level: u8Verbosity level (1-5). By default, the verbosity level is set to 3 (info level).
This verbosity level is shared by both stdout and file logging (if enabled).
stdout_quiet: boolIf set, no logs are printed to stdout.
stdout_format: LogFormatThe format of the logs printed to stdout. One of: full, json, pretty, compact.
full: The default rust log format. json: The logs are printed in JSON structured format. pretty: The logs are printed in a pretty, human readable format. compact: The logs are printed in a compact format.
file_directory: Option<PathBuf>The directory to store the log files. If not set, no logs are printed to files.
file_format: LogFormatThe format of the logs printed to log files. One of: full, json, pretty, compact.
full: The default rust log format. json: The logs are printed in JSON structured format. pretty: The logs are printed in a pretty, human readable format. compact: The logs are printed in a compact format.
file_rotation: LogRotationThe rotation of the log files. One of: hourly, daily, weekly, monthly, never. If set, new log files will be created every interval.