pub fn install()Expand description
Installs a SIGSEGV handler.
When SIGSEGV is delivered to the process, print a stack trace and then exit.
pub fn install()Installs a SIGSEGV handler.
When SIGSEGV is delivered to the process, print a stack trace and then exit.